function ssw_ftpurl2mirror, ftpurls, active=active, $
   local_path=local_path, packagenames=packagenames, outdir=outdir, $
   one_file=one_file, debug=debug
;
;+
;   Name: ssw_ftpurl2mirror
;
;   Purpose: - convert ftpurls to equivilent Mirror pkg, default passive ftp
;
;   Input Parameters:
;      ftpurls - one or more ftpurls, like ftp://[ftpserver]/[path]/[file]
;
;   Output:
;      function returns names of generated Mirror files
;   
;   Keyword Parameters:
;      active - if set, use active ftp Mirror (default is PASSIVE)
;      local_path - output path of ftp/Mirror file
;      outdir - output path for Mirror package(s) (def=curdir())
;      packagenames - optional file(names) for Mirror packages
;                     (default derived from ftpurl filenames)
;      one_file - if set, only generate one Mirror file
;                 default is one file per ftpurl
;
;   History:
;      10-Jan-2002 - S.L.Freeland, originally for firewall ssw installs 
;                    behind firewall (ftp clients may not support PASSIVE)
;                    ;
;   Restrictions: maybe only called by ssw installation server, but..      
;-

debug=keyword_set(debug)

if not data_chk(ftpurls,/string) then begin 
    box_message,'Supply at least one ftpurl..
    return,''
endif

needurls='ftp://'+str_replace(ftpurls,'ftp://','') ; 1 & only url prefix

break_url,needurls, rservers, rpaths, rfiles

nurls=n_elements(needurls)
if not data_chk(outdir,/string) then outdir=curdir()

case 1 of 
   n_elements(local_path) eq nurls: lpaths=local_paths
   n_elements(local_path) eq 1: lpaths=replicate(local_paths(0),nurls)
   else: lpaths=replicate(curdir(),nurls)
endcase


mirror_files=concat_dir(outdir,strsplit(rfiles,'.',/head))+'.mirror'

if debug then stop,'mirror_files'
if keyword_set(one_file) then begin
   mirror_files=mirror_files(0) 
   make_mirror,rservers,rpaths,lpaths,/mode_copy, do_deletes='false', $
      passive_ftp=(1-keyword_set(active)), get_patt=rfiles, $
      mirror_file=mirror_files
   mirror_files=mirror_f
endif else begin 
   for i=0,n_elements(needurls)-1 do begin 
      make_mirror,rservers(i),rpaths(i),lpaths(i),/mode_copy, $
         do_deletes='false', passive_ftp=(1-keyword_set(active)), $
         get_patt=rfiles(i), mirror_file=mirror_files(i)
   endfor
endelse

if debug then stop
return,mirror_files
end
